#!/usr/bin/perl -w
# $Id$
# Ian Beckwith <ianb@nessie.mcc.ac.uk>
#


package XML::PFIF;
use strict;
use POSIX;

use vars qw($VERSION);
$VERSION = '0.1'; # Version of module

sub new
{
    my $proto=shift;
    my $class=ref($proto) || $proto;
    my $self={};
    bless($self,$class);

    # FIXME:  not yet used
    # name of scraper or undef if not automated
    # $self->{automated}=shift; 
    
    return $self;
}


sub start_xml
{
    return "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
}



sub start_channel
{
    my ($self,$hash)=@_;
    my $str= "  <channel>\n";
    my $indent="    ";
    for my $field (@{$self->{channelfields}})
    {
	if(defined($hash) && exists($hash->{$field}))
	{
	    $self->{$field}=$hash->{$field};
	}
	else
	{
	    $self->{$field}='';
	}

	$str .=  $indent . $self->tag($field,$self->{$field});
    }
    return $str;
}

sub end_channel
{
    return "  </channel>\n";
}


sub tag
{
    my($self,$tag,$val)=@_;
    my $str='';
    if($val ne '')
    {
	$str="<$tag>$val</$tag>\n";
    }
    else
    {
	$str="<$tag/>\n";
    }
    return $str;
}


sub start_rss
{
    my $str=<<'EOT';
<rss version="2.0"
     xmlns:pfif="http://zesty.ca/pfif/1.1"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://zesty.ca/pfif/1.1
                         http://zesty.ca/pfif/1.1/pfif-1.1.xsd">
EOT
    return $str;
}

sub end_rss
{
    return "</rss>\n";
}

sub start_pfif
{
    my($self)=(@_);
    my $str=<<'EOT';
<pfif:pfif xmlns:pfif="http://zesty.ca/pfif/1.1"
           xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
           xsi:schemaLocation="http://zesty.ca/pfif/1.1
                               http://zesty.ca/pfif/1.1/pfif-1.1.xsd">
EOT
    return $str;
}

sub end_pfif
{
    return "</pfif:pfif>\n";
}

sub date_to_rfc822
{
    my($self,$indate)=@_;
    if($indate=~/^(\d\d\d\d)-(\d\d)-(\d\d)T(\d\d):(\d\d):(\d\d)Z/)
    {
	my($year,$month,$day,$hour,$min,$sec)=($1,$2,$3,$4,$5,$6);
	return POSIX::strftime("%a, %d %b %Y %H:%M:%S GMT",
			       $sec, $min, $hour, $day, ($month-1), ($year-1900));
    }
    return '';
}

sub now
{
    return POSIX::strftime("%Y-%m-%dT%H:%M:%SZ",gmtime(time()));
}

sub date_to_human
{
    my($self,$indate)=@_;
    if($indate=~/^(\d\d\d\d)-(\d\d)-(\d\d)T(\d\d):(\d\d):(\d\d)Z/)
    {
	my($year,$month,$day,$hour,$min,$sec)=($1,$2,$3,$4,$5,$6);
	return POSIX::strftime("%H:%M:%S GMT on %Y-%m-%d",
			       $sec, $min, $hour, $day, ($month-1), ($year-1900));
    }
    return '';
}


# Expected format: yyyy-mm-ddThh:mm:ssZ
sub validate_date
{
    my($self,$date)=@_;
    if($date=~/^(\d\d\d\d)-(\d\d)-(\d\d)T(\d\d):(\d\d):(\d\d)Z/)
    {
	my($years,$months,$days,$hours,$mins,$secs)=($1,$2,$3,$4,$5,$6);
	if(($months < 1) || ($months > 12))
	{
	    warn("validate_date: bad month: $months\n");
	    return 0;
	}
	if(($days < 1) || ($days > 31))
	{
	    warn("validate_date: bad day: $days\n");
	    return 0;
	}
	if(($hours < 0) || ($hours > 24))
	{
	    warn("validate_date: bad hour: $hours\n");
	    return 0;
	}
	if(($days < 1) || ($days > 31))
	{
	    warn("validate_date: bad day: $days\n");
	    return 0;
	}
	if(($mins < 0) || ($mins > 60))
	{
	    warn("validate_date: bad minute: $mins\n");
	    return 0;
	}
	if(($secs < 0) || ($secs > 60))
	{
	    warn("validate_date: bad second: $secs\n");
	    return 0;
	}
    }
    else
    {
	warn("validate_date: bad date format: expecting yyyy-mm-ddThh:mm:ssZ\n");
	return 0;
    }
	     
    return 1;
}


sub fixup_string
{
    my ($self,$str)=@_;

    my $achars="";
    my $aechars="";
    my $bchars="";
    my $cchars="";
    my $echars="";
    my $ichars="";
    my $nchars="";
    my $ochars="";
    my $uchars="";
    my $ychars="";

    $str=~s/[$achars]/A/g;
    $str=~s/[$aechars]/AE/g;
    $str=~s/[$bchars]/B/g;
    $str=~s/[$cchars]/C/g;
    $str=~s/[$echars]/E/g;
    $str=~s/[$ichars]/I/g;
    $str=~s/[$nchars]/N/g;
    $str=~s/[$ochars]/O/g;
    $str=~s/[$uchars]/U/g;
    $str=~s/[$ychars]/Y/g;

    $str=~tr/[a-z]/[A-Z]/;
    
    return $str;

}

1;

__END__

